
<p align="center">
    <img src="https://user-images.githubusercontent.com/43717493/114157274-19d14080-9941-11eb-84cd-aefa1775f9d6.png" width="230" height="230"><br/><br/>
    Simple yet flexible Data Analytics tool for Data Scientists.
</p>
<p align="center">
  <a href="https://github.com/23subbhashit/StoryTellar/issues"><img alt="GitHub issues" src="https://img.shields.io/github/issues/23subbhashit/StoryTellar"></a>
  <a href="https://github.com/23subbhashit/StoryTellar/network"><img alt="GitHub forks" src="https://img.shields.io/github/forks/23subbhashit/StoryTellar"></a>
  <a href="https://github.com/23subbhashit/StoryTellar/stargazers"><img alt="GitHub stars" src="https://img.shields.io/github/stars/23subbhashit/StoryTellar"></a>
  <a href="https://github.com/23subbhashit/StoryTellar/blob/master/LICENSE"><img alt="GitHub license" src="https://img.shields.io/github/license/23subbhashit/StoryTellar"></a>
  <a href="https://badge.fury.io/py/storyscience"><img src="https://badge.fury.io/py/storyscience.svg" alt="PyPI version" height="18"></a>
</p>


## Installation

```
pip install storyscience
```

## Build

```
python setup.py sdist bdist_wheel
```

## PYPI

```
twine upload dist/*
```
